summaryrefslogtreecommitdiff
path: root/src/mbgl/programs/segment.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mbgl/programs/segment.hpp')
-rw-r--r--src/mbgl/programs/segment.hpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mbgl/programs/segment.hpp b/src/mbgl/programs/segment.hpp
index 5158ce7dbf..5976550d2c 100644
--- a/src/mbgl/programs/segment.hpp
+++ b/src/mbgl/programs/segment.hpp
@@ -1,6 +1,6 @@
#pragma once
-#include <mbgl/gl/vertex_array.hpp>
+#include <mbgl/gfx/draw_scope.hpp>
#include <cstddef>
#include <vector>
@@ -8,7 +8,7 @@
namespace mbgl {
-template <class Attributes>
+template <class AttributeList>
class Segment {
public:
Segment(std::size_t vertexOffset_,
@@ -28,17 +28,17 @@ public:
std::size_t vertexLength;
std::size_t indexLength;
// One VertexArray per layer ID. This minimizes rebinding in cases where
// several layers share buckets but have different sets of active attributes.
// This can happen:
// * when two layers have the same layout properties, but differing
// data-driven paint properties
// * when two fill layers have the same layout properties, but one
// uses fill-color and the other uses fill-pattern
- mutable std::map<std::string, gl::VertexArray> vertexArrays;
+ mutable std::map<std::string, gfx::DrawScope> drawScopes;
};
-template <class Attributes>
-using SegmentVector = std::vector<Segment<Attributes>>;
+template <class AttributeList>
+using SegmentVector = std::vector<Segment<AttributeList>>;
} // namespace mbgl
@@ -28,17 +28,17 @@ public:
std::size_t vertexLength;
std::size_t indexLength;
- // One VertexArray per layer ID. This minimizes rebinding in cases where
+ // One DrawScope per layer ID. This minimizes rebinding in cases where
// several layers share buckets but have different sets of active attributes.
// This can happen: